package puntti;

/**
 * 
 * |------------------------------------------------------------------------|
 * | Luokan nimi:  Liikkeet                             | Avustajat:        |
 * |-------------------------------------------------------------------------
 * | Vastuualueet:                                      |                   |
 * |                                                    | - Liike           |
 * | - Pitää yllä liikkeitä. Osaa poistaa ja lisätä     |                   |
 * | liikkeen                                           |                   |
 * | - lukee ja kirjoittaa liikkeet tiedostoon          |                   |
 * | - osaa etsiä ja lajitella                          |                   |
 * |-------------------------------------------------------------------------
 * @author laspa
 * @version 5.3.2025
 *
 */
public class Liikkeet {
    
    private static final int MAX_LIIKKEITA = 5;
    
    private int lkm = 0;
    private Liike[] alkiot;
    
    
    /**
     * Alustava taulukko liikkeistä
     */
    public Liikkeet() {
        this.alkiot = new Liike[MAX_LIIKKEITA];
    }
    
    

    /**
     * Lisää uuden liikkeen tietorakenteeseen. Ottaa liikkeen omistukseensa.
     * @param liike Lisättävän liikkeen viite. Tietorakenne muuttuu omistajaksi.
     * @throws SailoException jos tietorakenteesee nei enää mahdu lisää.
     * <pre name="test">
     * #THROWS SailoException
     * Liikkeet liikkeet = new Liikkeet();
     * Liike kyykky1 = new Liike(), kyykky2 = new Liike();
     * liikkeet.getLkm() === 0;
     * liikkeet.lisaa(kyykky1); liikkeet.getLkm() === 1;
     * liikkeet.lisaa(kyykky2); liikkeet.getLkm() === 2;
     * liikkeet.lisaa(kyykky1); liikkeet.getLkm() === 3;
     * liikkeet.anna(0) === kyykky1;
     * liikkeet.anna(1) === kyykky2;
     * liikkeet.anna(2) === kyykky1; 
     * liikkeet.anna(1) == kyykky1 === false;
     * liikkeet.anna(1) == kyykky2 === true;
     * liikkeet.anna(3) === kyykky1; #THROWS IndexOutOfBoundsException
     * liikkeet.lisaa(kyykky1); liikkeet.getLkm() === 4;
     * liikkeet.lisaa(kyykky1); liikkeet.getLkm() === 5;  
     * liikkeet.lisaa(kyykky1); #THROWS SailoException 
     * </pre>
     */
    public void lisaa(Liike liike) throws SailoException {
        if (lkm >= alkiot.length) throw new SailoException("Liikaa alkioita");
            this.alkiot[this.lkm] = liike;
            this.lkm++;
    }
    
    
    /**
     * Palauttaa viitteen i:teen liikkeeseen
     * @param i monennen liikken viite halutaan
     * @return viite liikkeeseen jonka indeksi on i
     * @throws IndexOutOfBoundsException jos i ei ole sallitulla alueella.
     */
    public Liike anna(int i) throws IndexOutOfBoundsException{
        if (i < 0 || lkm <= i)
                throw new IndexOutOfBoundsException("Ei sallittu indeksi: " + i);
        return alkiot[i];
        
    }
    
    
    
    /**
     * Palauttaa liikkeiden määrän
     * @return liikkeiden määrän
     */
    public int getLkm() {
        return lkm;
    }
    
    
    /**
     * @param args ei käytössä
     */
    public static void main(String[] args) {
        Liikkeet liikkeet = new Liikkeet();
        Liike kyykky = new Liike();
        Liike kyykky2 = new Liike();
        
        kyykky.lisaaLiike();
        kyykky.taytaKyykky();
        kyykky2.lisaaLiike();
        kyykky2.taytaKyykky();
        
        try {
            
            liikkeet.lisaa(kyykky);
            liikkeet.lisaa(kyykky2);
            
            System.out.println("__________Liikkeet testi__________");
            
            for (int i = 0; i < liikkeet.getLkm(); i++) {
                Liike liike = liikkeet.anna(i);
                System.out.println("Liike indeksi " + i);
                liike.tulosta(System.out);
            }
            
        } catch (SailoException ex) {
            
            System.out.println(ex.getMessage());
        }
        
       
        
        
    
    } 

}
