/**
 * 
 */
package puntti;

import java.util.List;

/**
 * |------------------------------------------------------------------------|
 * | Luokan nimi:  Puntti                               | Avustajat:        |
 * |-------------------------------------------------------------------------
 * | Vastuualueet:                                      |                   |
 * |                                                    | - Liikkeet        |
 * | - Huolehtii Liikkeet ja Tulokset -luokkien         | - Tulos           |
 * | välisestä yhteistyöstä ja välittää näitä tietoja   | - Liike           |
 * | pyydettäessä                                       | - Tulokset        |
 * | - lukee ja kirjoittaa kerhon tiedostoon pyytämällä |                   |
 * | apuja avustajiltaan                                |                   |
 * |-------------------------------------------------------------------------
 * 
 * @author laspa
 * @version 5.3.2025
 *
 */
public class Puntti {
    
    private Liikkeet liikkeet = new Liikkeet();
    private Tulokset tulokset = new Tulokset();
    
    
    /**
     * Palautaa punti nliikkeiden määrän
     * @return liikemäärän
     */
    public int getLiikkeita() {
        return liikkeet.getLkm();
    }

    
    /**
     * Lisätään uusi liike
     * @param liike lisättävä liike
     * @throws SailoException kun lisääminen ei onnistu
     */
    public void lisaa(Liike liike) throws SailoException {
        liikkeet.lisaa(liike);
    }
    
    
    /**
     * Lisää uuden tuloksen punttiin
     * @param tulos lisättävä tulos
     */
    public void lisaa(Tulos tulos) {
        tulokset.lisaa(tulos);
    }
    
    
    /**
     * Palauttaa i:n liikkeen
     * @param i mones liike palautetaan
     * @return viite i:teen liikkeeseen
     * @throws IndexOutOfBoundsException jos i on epäsopiva
     */
    public Liike annaLiike(int i) {
        return liikkeet.anna(i);
    }
    
    
    /**
     * Haetaan liikkeen tulokset
     * @param liike jolle tuloksia haetaan
     * @return tietorakenne missä viitteet liikkeen tuloksiin
     */
    public List<Tulos> annaTulokset(Liike liike) {
        return tulokset.annaTulokset(liike.getLid());
    }
    
    

    /**
     * @param args ei käytössä
     */
    public static void main(String[] args) {
        Puntti puntti = new Puntti();
        
        
        
        try {
            
            Liike kyykky = new Liike();
            Liike kyykky2 = new Liike();
            
            kyykky.lisaaLiike();
            kyykky.taytaKyykky();
            
            kyykky2.lisaaLiike();
            kyykky2.taytaKyykky();
            
            puntti.lisaa(kyykky);
            puntti.lisaa(kyykky2);
            
            
            Tulos penkki1 = new Tulos();
            penkki1.taytaPenkkiTulos(kyykky2.getLid());
            Tulos penkki2 = new Tulos();
            penkki2.taytaPenkkiTulos(kyykky.getLid());
            Tulos penkki3 = new Tulos();
            penkki3.taytaPenkkiTulos(kyykky2.getLid());
            Tulos penkki4 = new Tulos();
            penkki4.taytaPenkkiTulos(kyykky2.getLid());
            
            puntti.lisaa(penkki1);
            puntti.lisaa(penkki2);
            puntti.lisaa(penkki3);
            puntti.lisaa(penkki4);
            
            for (int i = 0; i < puntti.getLiikkeita(); i++) {
                Liike liike = puntti.annaLiike(i);
                System.out.println("Liike indeksi " + i);
                liike.tulosta(System.out);
            
            
            List<Tulos> tulokset = puntti.annaTulokset(liike);
                    
                    for (Tulos tulo: tulokset) {
                        System.out.println(tulo.getLid() + " ");
                    tulo.tulosta(System.out);
                }
                    System.out.println();
            
            }
            } catch (SailoException e) {
            System.err.println(e.getMessage());
            
        }
        
        
    


}


}
