package puntti;

import java.util.ArrayList;
import java.util.Collection;
import java.util.List;

/**
 * |------------------------------------------------------------------------|
 * | Luokan nimi:  Tulokset                             | Avustajat:        |
 * |-------------------------------------------------------------------------
 * | Vastuualueet:                                      |                   |
 * |                                                    | - Tulos           |
 * | - Pitää yllä tuloksia. Osaa poistaa ja lisätä      |                   |
 * | liikkeen                                           |                   |
 * | - lukee ja kirjoittaa liikkeet tiedostoon          |                   |
 * | - osaa etsiä ja lajitella                          |                   |
 * |-------------------------------------------------------------------------
 * @author laspa
 * @version 11.3.2025
 *
 */
public class Tulokset {
    
    private Collection<Tulos> alkiot = new ArrayList<Tulos>();
    
    
    /**
     * alustetaan tulokset
     */
    public Tulokset(){
        //ei tarvitse sillä alustetaan yläpuolellea
    }
    
    /**
     * @param tulos liättävä tulos
     */
    public void lisaa(Tulos tulos) {
        alkiot.add(tulos);        
    }
    
    /**
     * Haetaan kaikki liikkeen tulokset
     * @param id liikkeen id jolla haetaan tuloksia
     * @return tietorakenne jossa on viitteet löydettyihin tuloksiin
     * @example
     * <pre name="test">
     * #import java.util.*;
     * 
     *  Tulokset tulokset = new Tulokset();
     *  Tulos penkki1 = new Tulos(2); tuulokset.lisaa(penkki1);
     *  Tulos penkki2 = new Tulos(1); tuulokset.lisaa(penkki2);
     *  Tulos penkki3 = new Tulos(2); tuulokset.lisaa(penkki3);
     *  Tulos penkki4 = new Tulos(1); tuulokset.lisaa(penkki4);
     *  Tulos penkki5 = new Tulos(2); tuulokset.lisaa(penkki5);
     *  Tulos penkki6 = new Tulos(4); tuulokset.lisaa(penkki6);
     *  
     *  List<Tulos> loytyneet;
     *  loytyneet = tuulokset.annaTulokset(3);
     *  loytyneet.size() === 0; 
     *  loytyneet = tuulokset.annaTulokset(1);
     *  loytyneet.size() === 2; 
     *  loytyneet.get(0) == penkki2 === true;
     *  loytyneet.get(1) == penkki4 === true;
     *  loytyneet = tuulokset.annaTulokset(4);
     *  loytyneet.size() === 1; 
     *  loytyneet.get(0) == penkki6 === true;
     * </pre> 
     */
    public List<Tulos> annaTulokset(int id) {
        List<Tulos> loytyneet = new ArrayList<Tulos>();
        for (Tulos tulo: alkiot)
            if (tulo.getLid() == id) loytyneet.add(tulo);
        return loytyneet;
    }
    
    
    
    
    /**
     * Testiohjelma tulokset luokalle
     * @param args ei kaytossa
     */
    public static void main(String[] args) {
        
        Tulokset tuulokset = new Tulokset();
        Tulos penkki1 = new Tulos();
        penkki1.taytaPenkkiTulos(1);
        Tulos penkki2 = new Tulos();
        penkki2.taytaPenkkiTulos(2);
        Tulos penkki3 = new Tulos();
        penkki3.taytaPenkkiTulos(2);
        Tulos penkki4 = new Tulos();
        penkki4.taytaPenkkiTulos(2);
        
        tuulokset.lisaa(penkki1);
        tuulokset.lisaa(penkki2);
        tuulokset.lisaa(penkki3);
        tuulokset.lisaa(penkki4);
        
        System.out.println("__________ Tulokset testi__________");
        
        List<Tulos> tulokset1 = tuulokset.annaTulokset(1);
        
        for (Tulos tulo: tulokset1) {
            System.out.println(tulo.getLid() + " ");
            tulo.tulosta(System.out);
        }
    }




}
